# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
from enum import Enum


class BinarySettings(Enum):
    """
    Named constants for all Zaber Binary protocol settings.
    """

    ACCELERATION = 0
    ACCELERATION_ONLY = 1
    ALIAS_NUMBER = 2
    ANALOG_INPUT_COUNT = 3
    ANALOG_OUTPUT_COUNT = 4
    AUTO_HOME_DISABLED_MODE = 5
    AUTO_REPLY_DISABLED_MODE = 6
    AXIS_DEVICE_NUMBER = 7
    AXIS_INVERSION = 8
    AXIS_VELOCITY_PROFILE = 9
    AXIS_VELOCITY_SCALE = 10
    BAUD_RATE = 11
    CALIBRATED_ENCODER_COUNT = 12
    CALIBRATION_ERROR = 13
    CALIBRATION_TYPE = 14
    CLOSED_LOOP_MODE = 15
    CURRENT_POSITION = 16
    CYCLE_DISTANCE = 17
    DECELERATION_ONLY = 18
    DEVICE_DIRECTION = 19
    DEVICE_ID = 20
    DEVICE_MODE = 21
    DIGITAL_INPUT_COUNT = 22
    DIGITAL_OUTPUT_COUNT = 23
    ENCODER_COUNT = 24
    ENCODER_POSITION = 25
    FILTER_HOLDER_ID = 26
    FIRMWARE_BUILD = 27
    FIRMWARE_VERSION = 28
    HOLD_CURRENT = 29
    HOME_OFFSET = 30
    HOME_SENSOR_TYPE = 31
    HOME_SPEED = 32
    HOME_STATUS = 33
    INDEX_DISTANCE = 34
    JOYSTICK_CALIBRATION_MODE = 35
    KNOB_DIRECTION = 36
    KNOB_DISABLED_MODE = 37
    KNOB_JOG_SIZE = 38
    KNOB_MOVEMENT_MODE = 39
    KNOB_VELOCITY_PROFILE = 40
    KNOB_VELOCITY_SCALE = 41
    LOCK_STATE = 42
    MANUAL_MOVE_TRACKING_DISABLED_MODE = 43
    MAXIMUM_POSITION = 44
    MAXIMUM_RELATIVE_MOVE = 45
    MESSAGE_ID_MODE = 46
    MICROSTEP_RESOLUTION = 47
    MINIMUM_POSITION = 48
    MOVE_TRACKING_MODE = 49
    MOVE_TRACKING_PERIOD = 50
    PARK_STATE = 51
    PERIPHERAL_ID = 52
    PERIPHERAL_SERIAL_NUMBER = 53
    POWER_SUPPLY_VOLTAGE = 54
    PROTOCOL = 55
    RUNNING_CURRENT = 56
    SERIAL_NUMBER = 57
    SERVO_CHANNEL = 58
    SLIP_TRACKING_PERIOD = 59
    STALL_TIMEOUT = 60
    STATUS = 61
    TARGET_SPEED = 62
