# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
from enum import Enum


class ErrorCode(Enum):
    """
    Named constants for all Zaber Binary protocol error codes.
    """

    CANNOT_HOME = 1
    DEVICE_NUMBER_INVALID = 2
    ADDRESS_INVALID = 5
    VOLTAGE_LOW = 14
    VOLTAGE_HIGH = 15
    STORED_POSITION_INVALID = 18
    ABSOLUTE_POSITION_INVALID = 20
    RELATIVE_POSITION_INVALID = 21
    VELOCITY_INVALID = 22
    AXIS_INVALID = 25
    AXIS_DEVICE_NUMBER_INVALID = 26
    INVERSION_INVALID = 27
    VELOCITY_PROFILE_INVALID = 28
    VELOCITY_SCALE_INVALID = 29
    LOAD_EVENT_INVALID = 30
    RETURN_EVENT_INVALID = 31
    JOYSTICK_CALIBRATION_MODE_INVALID = 33
    PERIPHERAL_ID_INVALID = 36
    RESOLUTION_INVALID = 37
    RUN_CURRENT_INVALID = 38
    HOLD_CURRENT_INVALID = 39
    MODE_INVALID = 40
    HOME_SPEED_INVALID = 41
    SPEED_INVALID = 42
    ACCELERATION_INVALID = 43
    MAXIMUM_POSITION_INVALID = 44
    CURRENT_POSITION_INVALID = 45
    MAXIMUM_RELATIVE_MOVE_INVALID = 46
    OFFSET_INVALID = 47
    ALIAS_INVALID = 48
    LOCK_STATE_INVALID = 49
    DEVICE_ID_UNKNOWN = 50
    SETTING_INVALID = 53
    COMMAND_INVALID = 64
    PARK_STATE_INVALID = 65
    TEMPERATURE_HIGH = 67
    DIGITAL_INPUT_PIN_INVALID = 68
    DIGITAL_OUTPUT_PIN_INVALID = 71
    DIGITAL_OUTPUT_MASK_INVALID = 74
    ANALOG_INPUT_PIN_INVALID = 76
    MOVE_INDEX_NUMBER_INVALID = 78
    INDEX_DISTANCE_INVALID = 79
    CYCLE_DISTANCE_INVALID = 80
    FILTER_HOLDER_ID_INVALID = 81
    ABSOLUTE_FORCE_INVALID = 87
    AUTO_REPLY_DISABLED_MODE_INVALID = 101
    MESSAGE_ID_MODE_INVALID = 102
    HOME_STATUS_INVALID = 103
    HOME_SENSOR_TYPE_INVALID = 104
    AUTO_HOME_DISABLED_MODE_INVALID = 105
    MINIMUM_POSITION_INVALID = 106
    KNOB_DISABLED_MODE_INVALID = 107
    KNOB_DIRECTION_INVALID = 108
    KNOB_MOVEMENT_MODE_INVALID = 109
    KNOB_JOG_SIZE_INVALID = 110
    KNOB_VELOCITY_SCALE_INVALID = 111
    KNOB_VELOCITY_PROFILE_INVALID = 112
    ACCELERATION_ONLY_INVALID = 113
    DECELERATION_ONLY_INVALID = 114
    MOVE_TRACKING_MODE_INVALID = 115
    MANUAL_MOVE_TRACKING_DISABLED_MODE_INVALID = 116
    MOVE_TRACKING_PERIOD_INVALID = 117
    CLOSED_LOOP_MODE_INVALID = 118
    SLIP_TRACKING_PERIOD_INVALID = 119
    STALL_TIMEOUT_INVALID = 120
    DEVICE_DIRECTION_INVALID = 121
    BAUD_RATE_INVALID = 122
    PROTOCOL_INVALID = 123
    BAUD_RATE_OR_PROTOCOL_INVALID = 124
    BUSY = 255
    SYSTEM_ERROR = 257
    STORAGE_FULL = 401
    REGISTER_ADDRESS_INVALID = 701
    REGISTER_VALUE_INVALID = 702
    SAVE_POSITION_INVALID = 1600
    SAVE_POSITION_NOT_HOMED = 1601
    RETURN_POSITION_INVALID = 1700
    MOVE_POSITION_INVALID = 1800
    MOVE_POSITION_NOT_HOMED = 1801
    RELATIVE_POSITION_LIMITED = 2146
    SETTINGS_LOCKED = 3600
    BIT_1_INVALID = 4001
    BIT_2_INVALID = 4002
    DISABLE_AUTO_HOME_INVALID = 4008
    BIT_10_INVALID = 4010
    BIT_11_INVALID = 4011
    HOME_SWITCH_INVALID = 4012
    BIT_13_INVALID = 4013
    BIT_14_INVALID = 4014
    BIT_15_INVALID = 4015
    DEVICE_PARKED = 6501
    DRIVER_DISABLED = 9001
