# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from .motion_lib_exception import MotionLibException


class IoChannelOutOfRangeException(MotionLibException):
    """
    Thrown when a device IO operation cannot be performed because the provided channel is not valid.
    """
